==> centreon-web-23.04.26.tar.gz: centreon-web-23.04.26/src/Core/Security/ProviderConfiguration/Domain/LoginLoggerInterface.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Security\ProviderConfiguration\Domain;

use Exception;

/**
 * This interface is used on authentication only
 */
interface LoginLoggerInterface
{
    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     * @return void
     */
    public function info(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     * @return void
     */
    public function debug(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     * @return void
     */
    public function error(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param Exception $exception
     * @return void
     */
    public function exception(string $scope, string $message, Exception $exception): void;
}

==> centreon-web-23.10.29.tar.gz: centreon-web-23.10.29/src/Core/Security/ProviderConfiguration/Domain/LoginLoggerInterface.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Security\ProviderConfiguration\Domain;

use Exception;

/**
 * This interface is used on authentication only.
 */
interface LoginLoggerInterface
{
    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     */
    public function info(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     */
    public function debug(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param array<string,string> $content
     */
    public function error(string $scope, string $message, array $content = []): void;

    /**
     * @param string $scope
     * @param string $message
     * @param Exception $exception
     */
    public function exception(string $scope, string $message, Exception $exception): void;
}
